# coding: utf-8

"""
    Swagger Petstore - OpenAPI 3.0

    This is a sample Pet Store Server based on the OpenAPI 3.0 specification.  You can find out more about Swagger at [http://swagger.io](http://swagger.io). In the third iteration of the pet store, we've switched to the design first approach! You can now help us improve the API whether it's by making changes to the definition itself or to the code. That way, with time, we can improve the API in general, and expose some of the new features in OAS3.  Some useful links: - [The Pet Store repository](https://github.com/swagger-api/swagger-petstore) - [The source API definition for the Pet Store](https://github.com/swagger-api/swagger-petstore/blob/master/src/main/resources/openapi.yaml)

    The version of the OpenAPI document: 1.0.19
    Contact: apiteam@swagger.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from temp_123_ti_client.api.store_api import StoreApi


class TestStoreApi(unittest.TestCase):
    """StoreApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StoreApi()

    def tearDown(self) -> None:
        pass

    def test_delete_order(self) -> None:
        """Test case for delete_order

        Delete purchase order by ID
        """
        pass

    def test_get_inventory(self) -> None:
        """Test case for get_inventory

        Returns pet inventories by status
        """
        pass

    def test_get_order_by_id(self) -> None:
        """Test case for get_order_by_id

        Find purchase order by ID
        """
        pass

    def test_place_order(self) -> None:
        """Test case for place_order

        Place an order for a pet
        """
        pass


if __name__ == '__main__':
    unittest.main()
