# coding: utf-8

"""
    Swagger Petstore - OpenAPI 3.0

    This is a sample Pet Store Server based on the OpenAPI 3.0 specification.  You can find out more about Swagger at [http://swagger.io](http://swagger.io). In the third iteration of the pet store, we've switched to the design first approach! You can now help us improve the API whether it's by making changes to the definition itself or to the code. That way, with time, we can improve the API in general, and expose some of the new features in OAS3.  Some useful links: - [The Pet Store repository](https://github.com/swagger-api/swagger-petstore) - [The source API definition for the Pet Store](https://github.com/swagger-api/swagger-petstore/blob/master/src/main/resources/openapi.yaml)

    The version of the OpenAPI document: 1.0.19
    Contact: apiteam@swagger.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from temp_123_ti_client.api.user_api import UserApi


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UserApi()

    def tearDown(self) -> None:
        pass

    def test_create_user(self) -> None:
        """Test case for create_user

        Create user
        """
        pass

    def test_create_users_with_list_input(self) -> None:
        """Test case for create_users_with_list_input

        Creates list of users with given input array
        """
        pass

    def test_delete_user(self) -> None:
        """Test case for delete_user

        Delete user
        """
        pass

    def test_get_user_by_name(self) -> None:
        """Test case for get_user_by_name

        Get user by user name
        """
        pass

    def test_login_user(self) -> None:
        """Test case for login_user

        Logs user into the system
        """
        pass

    def test_logout_user(self) -> None:
        """Test case for logout_user

        Logs out current logged in user session
        """
        pass

    def test_update_user(self) -> None:
        """Test case for update_user

        Update user
        """
        pass


if __name__ == '__main__':
    unittest.main()
